Learn R Programming

splicegear (version 1.44.0)

buildSpliceSites: Functions to query PALSdb

Description

Functions to make a query on PALSdb, and build objects from the result of a query.

Usage

queryPALSdb(query, disp = c("data", "browser"), field = c("keyword", "ug.id", "gb.id", "human.cytoband", "mouse.cytoband", "cluster_count"), species = c("human", "mouse"), e.value = "1e-1", ident.threshold = c("90% 50b", "95% 50b", "90% 45b"))
getPALSdbURL(query, disp = c("data", "browser"), field = c("keyword", "ug.id", "gb.id", "human.cytoband", "mouse.cytoband", "cluster_count"), species = c("human", "mouse"), e.value = "1e-1", ident.threshold = c("90% 50b", "95% 50b", "90% 45b"))
buildSpliceSites(xml, verbose=TRUE)

Arguments

query
query string
xml
an object of class XML (as returned by xmlTreeParse)
disp
(idem genbank and pubmed)
field
The field on which the query will be based
species
the specie to work with
e.value
E-value
ident.threshold
threshold for matching sequences
verbose
verbose output.

Value

An object of class XML for queryPALSdb, an URL for getPALSdbURL or a list of objects of class SpliceSites.

Details

queryPALSdb returns an an object of class XML when disp = "data".

The function buildSpliceSites constructs SpliceSites objects from the XML data. The variables in the slots spsiteIpos.pData and spsiteIIpos.pData are at least tissue (tissue information), histology and site (site numbering).

References

"Standardazed output for putative alternative splicing: application to the study of splice variants with microarrays", Gautier L. et al., 2003, manuscript in preparation.

See Also

queryPALSdb

Examples

Run this code
library(XML)

filename <- system.file("extdata", "example.xml", package="splicegear")

xml <- xmlTreeParse(filename, asTree=TRUE)

spsites <- buildSpliceSites(xml)

Run the code above in your browser using DataLab