Learn R Programming

splicegear (version 1.44.0)

isProbeOnSpliceSite: Check the presence of probes on certain exons

Description

Return whether the probes are located on exons involved in (putative) alternative splicing or not.

Usage

isProbeOnSpliceSite(probes, spSites) ## isSpliceSiteOnProbe is not yet implemented

Arguments

probes
object of class Probes
spSites
object of class spliceSites

Value

The returned value in a list of two vectors of mode logical of the same length:
isintypeI
whether the probes are in a `type I' region or not.
isintypeII
whether the probe are in a `type II' region or not.

Details

References

For details about `type I' and `type II', please refer to Huang Y.-H and Chen Y.-T and Lai J.-J. and Yang S.-T. and Yang U.-C., PALSdb: Putative Alternative Splicing database, Nucleic Acids Research, 2002, pages 186-190

Examples

Run this code

Run the code above in your browser using DataLab