Learn R Programming

splicegear (version 1.44.0)

spliceset: Example data for splicegear

Description

The putative splice variants for a reference sequence, the matching probes from the Affymetrix chip 'HG-U95A' and probe intensities from the 'dilution' dataset.

Usage

#data(eset, package="splicegear") #data(probes, package="splicegear") #data(spsites, package="splicegear") #data(spliceset, package="splicegear")

Arguments

Format

The formats are objects of class ExpressionSet-class, Probes-class, SpliceSites-class and SpliceExprSet-class respectively.

Details

The attribute "name" is set to the ID of the Unigene cluster from which the reference sequence is taken.

References

"PALSdb", ref. GeneLogic's dilution dataset.

Examples

Run this code
data(spliceset, package="splicegear")

plot(spliceset, main=attr(spliceset, "name"))

Run the code above in your browser using DataLab